Title: [240918] trunk/Source
Revision
240918
Author
an...@apple.com
Date
2019-02-04 04:48:21 -0800 (Mon, 04 Feb 2019)

Log Message

Source/WebCore:
Rename GraphicsLayer and PlatformCALayer scrolling layer type enum values to be less ambiguous
https://bugs.webkit.org/show_bug.cgi?id=194215

Reviewed by Frédéric Wang.

GraphicsLayer::Type::Scrolling -> GraphicsLayer::Type::ScrollContainer
PlatformCALayer::LayerTypeScrollingLayer -> PlatformCALayer::LayerTypeScrollContainerLayer

* platform/graphics/GraphicsLayer.cpp:
(WebCore::GraphicsLayer::supportsLayerType):
* platform/graphics/GraphicsLayer.h:
* platform/graphics/ca/GraphicsLayerCA.cpp:
(WebCore::GraphicsLayer::supportsLayerType):
(WebCore::GraphicsLayerCA::initialize):
* platform/graphics/ca/PlatformCALayer.cpp:
(WebCore::operator<<):
* platform/graphics/ca/PlatformCALayer.h:
* platform/graphics/ca/cocoa/PlatformCALayerCocoa.mm:
(WebCore::PlatformCALayerCocoa::PlatformCALayerCocoa):
(WebCore::PlatformCALayerCocoa::commonInit):
* rendering/RenderLayerBacking.cpp:
(WebCore::RenderLayerBacking::updateScrollingLayers):
* rendering/RenderLayerCompositor.cpp:
(WebCore::RenderLayerCompositor::ensureRootLayer):

Source/WebKit:
Rename GraphicsLayer and PlatformCALayer type enum values to match "scroll container layer" convention
https://bugs.webkit.org/show_bug.cgi?id=194215

Reviewed by Frédéric Wang.

* Shared/RemoteLayerTree/RemoteLayerBackingStore.mm:
(WebKit::RemoteLayerBackingStore::drawInContext):
* UIProcess/RemoteLayerTree/RemoteLayerTreeHost.mm:
(WebKit::RemoteLayerTreeHost::makeNode):
* UIProcess/RemoteLayerTree/ios/RemoteLayerTreeHostIOS.mm:
(WebKit::RemoteLayerTreeHost::makeNode):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (240917 => 240918)


--- trunk/Source/WebCore/ChangeLog	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/ChangeLog	2019-02-04 12:48:21 UTC (rev 240918)
@@ -1,3 +1,30 @@
+2019-02-04  Antti Koivisto  <an...@apple.com>
+
+        Rename GraphicsLayer and PlatformCALayer scrolling layer type enum values to be less ambiguous
+        https://bugs.webkit.org/show_bug.cgi?id=194215
+
+        Reviewed by Frédéric Wang.
+
+        GraphicsLayer::Type::Scrolling -> GraphicsLayer::Type::ScrollContainer
+        PlatformCALayer::LayerTypeScrollingLayer -> PlatformCALayer::LayerTypeScrollContainerLayer
+
+        * platform/graphics/GraphicsLayer.cpp:
+        (WebCore::GraphicsLayer::supportsLayerType):
+        * platform/graphics/GraphicsLayer.h:
+        * platform/graphics/ca/GraphicsLayerCA.cpp:
+        (WebCore::GraphicsLayer::supportsLayerType):
+        (WebCore::GraphicsLayerCA::initialize):
+        * platform/graphics/ca/PlatformCALayer.cpp:
+        (WebCore::operator<<):
+        * platform/graphics/ca/PlatformCALayer.h:
+        * platform/graphics/ca/cocoa/PlatformCALayerCocoa.mm:
+        (WebCore::PlatformCALayerCocoa::PlatformCALayerCocoa):
+        (WebCore::PlatformCALayerCocoa::commonInit):
+        * rendering/RenderLayerBacking.cpp:
+        (WebCore::RenderLayerBacking::updateScrollingLayers):
+        * rendering/RenderLayerCompositor.cpp:
+        (WebCore::RenderLayerCompositor::ensureRootLayer):
+
 2019-02-03  Antti Koivisto  <an...@apple.com>
 
         [iOS] Tiles not created in large scrollable iframes

Modified: trunk/Source/WebCore/platform/graphics/GraphicsLayer.cpp (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/GraphicsLayer.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/GraphicsLayer.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -78,7 +78,7 @@
     switch (type) {
     case Type::Normal:
     case Type::PageTiledBacking:
-    case Type::Scrolling:
+    case Type::ScrollContainer:
         return true;
     case Type::Shape:
         return false;

Modified: trunk/Source/WebCore/platform/graphics/GraphicsLayer.h (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/GraphicsLayer.h	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/GraphicsLayer.h	2019-02-04 12:48:21 UTC (rev 240918)
@@ -237,7 +237,7 @@
     enum class Type : uint8_t {
         Normal,
         PageTiledBacking,
-        Scrolling,
+        ScrollContainer,
         Shape
     };
 

Modified: trunk/Source/WebCore/platform/graphics/ca/GraphicsLayerCA.cpp (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/ca/GraphicsLayerCA.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/ca/GraphicsLayerCA.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -300,7 +300,7 @@
     switch (type) {
     case Type::Normal:
     case Type::PageTiledBacking:
-    case Type::Scrolling:
+    case Type::ScrollContainer:
         return true;
     case Type::Shape:
 #if PLATFORM(COCOA)
@@ -417,8 +417,8 @@
     case Type::PageTiledBacking:
         platformLayerType = PlatformCALayer::LayerType::LayerTypePageTiledBackingLayer;
         break;
-    case Type::Scrolling:
-        platformLayerType = PlatformCALayer::LayerType::LayerTypeScrollingLayer;
+    case Type::ScrollContainer:
+        platformLayerType = PlatformCALayer::LayerType::LayerTypeScrollContainerLayer;
         break;
     case Type::Shape:
         platformLayerType = PlatformCALayer::LayerType::LayerTypeShapeLayer;

Modified: trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.cpp (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -228,8 +228,8 @@
     case PlatformCALayer::LayerTypeShapeLayer:
         ts << "shape-layer";
         break;
-    case PlatformCALayer::LayerTypeScrollingLayer:
-        ts << "scrolling-layer";
+    case PlatformCALayer::LayerTypeScrollContainerLayer:
+        ts << "scroll-container-layer";
         break;
     case PlatformCALayer::LayerTypeCustom:
         ts << "custom-layer";

Modified: trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.h (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.h	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/ca/PlatformCALayer.h	2019-02-04 12:48:21 UTC (rev 240918)
@@ -75,7 +75,7 @@
         LayerTypeShapeLayer,
         LayerTypeLightSystemBackdropLayer,
         LayerTypeDarkSystemBackdropLayer,
-        LayerTypeScrollingLayer,
+        LayerTypeScrollContainerLayer,
         LayerTypeEditableImageLayer,
         LayerTypeCustom,
     };

Modified: trunk/Source/WebCore/platform/graphics/ca/cocoa/PlatformCALayerCocoa.mm (240917 => 240918)


--- trunk/Source/WebCore/platform/graphics/ca/win/PlatformCALayerWin.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/ca/win/PlatformCALayerWin.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -778,7 +778,7 @@
     case PlatformCALayer::LayerTypeShapeLayer: layerTypeName = "shape-layer"; break;
     case PlatformCALayer::LayerTypeLightSystemBackdropLayer: layerTypeName = "light-system-backdrop-layer"; break;
     case PlatformCALayer::LayerTypeDarkSystemBackdropLayer: layerTypeName = "dark-system-backdrop-layer"; break;
-    case PlatformCALayer::LayerTypeScrollingLayer: layerTypeName = "scrolling-layer"; break;
+    case PlatformCALayer::LayerTypeScrollContainerLayer: layerTypeName = "scroll-container-layer"; break;
     case PlatformCALayer::LayerTypeCustom: layerTypeName = "custom-layer"; break;
     }
 

Modified: trunk/Source/WebCore/rendering/RenderLayerBacking.cpp (240917 => 240918)


--- trunk/Source/WebCore/rendering/RenderLayerBacking.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/rendering/RenderLayerBacking.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -1743,7 +1743,7 @@
 
     if (!m_scrollContainerLayer) {
         // Outer layer which corresponds with the scroll view.
-        m_scrollContainerLayer = createGraphicsLayer("scrolling container", GraphicsLayer::Type::Scrolling);
+        m_scrollContainerLayer = createGraphicsLayer("scroll container", GraphicsLayer::Type::ScrollContainer);
         m_scrollContainerLayer->setDrawsContent(false);
         m_scrollContainerLayer->setMasksToBounds(true);
 

Modified: trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp (240917 => 240918)


--- trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2019-02-04 12:48:21 UTC (rev 240918)
@@ -3441,14 +3441,14 @@
             m_overflowControlsHostLayer->setName("overflow controls host");
 
             m_scrolledContentsLayer = GraphicsLayer::create(graphicsLayerFactory(), *this);
-            m_scrolledContentsLayer->setName("scrolled contents layer");
+            m_scrolledContentsLayer->setName("scrolled contents");
             m_scrolledContentsLayer->setAnchorPoint({ });
 
 #if PLATFORM(IOS_FAMILY)
             if (m_renderView.settings().asyncFrameScrollingEnabled()) {
-                m_scrollContainerLayer = GraphicsLayer::create(graphicsLayerFactory(), *this, GraphicsLayer::Type::Scrolling);
+                m_scrollContainerLayer = GraphicsLayer::create(graphicsLayerFactory(), *this, GraphicsLayer::Type::ScrollContainer);
 
-                m_scrollContainerLayer->setName("scroll containers layer");
+                m_scrollContainerLayer->setName("scroll container");
                 m_scrollContainerLayer->setMasksToBounds(true);
                 m_scrollContainerLayer->setAnchorPoint({ });
 

Modified: trunk/Source/WebKit/ChangeLog (240917 => 240918)


--- trunk/Source/WebKit/ChangeLog	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebKit/ChangeLog	2019-02-04 12:48:21 UTC (rev 240918)
@@ -1,3 +1,17 @@
+2019-02-04  Antti Koivisto  <an...@apple.com>
+
+        Rename GraphicsLayer and PlatformCALayer type enum values to match "scroll container layer" convention
+        https://bugs.webkit.org/show_bug.cgi?id=194215
+
+        Reviewed by Frédéric Wang.
+
+        * Shared/RemoteLayerTree/RemoteLayerBackingStore.mm:
+        (WebKit::RemoteLayerBackingStore::drawInContext):
+        * UIProcess/RemoteLayerTree/RemoteLayerTreeHost.mm:
+        (WebKit::RemoteLayerTreeHost::makeNode):
+        * UIProcess/RemoteLayerTree/ios/RemoteLayerTreeHostIOS.mm:
+        (WebKit::RemoteLayerTreeHost::makeNode):
+
 2019-02-03  Antti Koivisto  <an...@apple.com>
 
         [iOS] Tiles not created in large scrollable iframes

Modified: trunk/Source/WebKit/Shared/RemoteLayerTree/RemoteLayerBackingStore.mm (240917 => 240918)


--- trunk/Source/WebKit/Shared/RemoteLayerTree/RemoteLayerBackingStore.mm	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebKit/Shared/RemoteLayerTree/RemoteLayerBackingStore.mm	2019-02-04 12:48:21 UTC (rev 240918)
@@ -368,7 +368,7 @@
     case WebCore::PlatformCALayer::LayerTypeAVPlayerLayer:
     case WebCore::PlatformCALayer::LayerTypeContentsProvidedLayer:
     case WebCore::PlatformCALayer::LayerTypeShapeLayer:
-    case WebCore::PlatformCALayer::LayerTypeScrollingLayer:
+    case WebCore::PlatformCALayer::LayerTypeScrollContainerLayer:
     case WebCore::PlatformCALayer::LayerTypeEditableImageLayer:
     case WebCore::PlatformCALayer::LayerTypeCustom:
         ASSERT_NOT_REACHED();

Modified: trunk/Source/WebKit/UIProcess/RemoteLayerTree/RemoteLayerTreeHost.mm (240917 => 240918)


--- trunk/Source/WebKit/UIProcess/RemoteLayerTree/RemoteLayerTreeHost.mm	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebKit/UIProcess/RemoteLayerTree/RemoteLayerTreeHost.mm	2019-02-04 12:48:21 UTC (rev 240918)
@@ -260,7 +260,7 @@
     case PlatformCALayer::LayerTypeTiledBackingLayer:
     case PlatformCALayer::LayerTypePageTiledBackingLayer:
     case PlatformCALayer::LayerTypeTiledBackingTileLayer:
-    case PlatformCALayer::LayerTypeScrollingLayer:
+    case PlatformCALayer::LayerTypeScrollContainerLayer:
     case PlatformCALayer::LayerTypeEditableImageLayer:
         return RemoteLayerTreeNode::createWithPlainLayer(properties.layerID);
 

Modified: trunk/Source/WebKit/UIProcess/RemoteLayerTree/ios/RemoteLayerTreeHostIOS.mm (240917 => 240918)


--- trunk/Source/WebKit/UIProcess/RemoteLayerTree/ios/RemoteLayerTreeHostIOS.mm	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebKit/UIProcess/RemoteLayerTree/ios/RemoteLayerTreeHostIOS.mm	2019-02-04 12:48:21 UTC (rev 240918)
@@ -108,7 +108,7 @@
     case PlatformCALayer::LayerTypeShapeLayer:
         return makeAdoptingView([[WKShapeView alloc] init]);
 
-    case PlatformCALayer::LayerTypeScrollingLayer:
+    case PlatformCALayer::LayerTypeScrollContainerLayer:
         if (!m_isDebugLayerTreeHost)
             return makeAdoptingView([[WKChildScrollView alloc] init]);
         // The debug indicator parents views under layers, which can cause crashes with UIScrollView.
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/platform/graphics/ca/cocoa/PlatformCALayerCocoa.mm	2019-02-04 08:15:46 UTC (rev 240917)
+++ trunk/Source/WebCore/platform/graphics/ca/cocoa/PlatformCALayerCocoa.mm	2019-02-04 12:48:21 UTC (rev 240918)
@@ -230,8 +230,8 @@
     case LayerTypeRootLayer:
         layerClass = [CALayer class];
         break;
-    case LayerTypeScrollingLayer:
-        // Scrolling layers only have special behavior with PlatformCALayerRemote.
+    case LayerTypeScrollContainerLayer:
+        // Scroll container layers only have special behavior with PlatformCALayerRemote.
         // fallthrough
     case LayerTypeEditableImageLayer:
     case LayerTypeWebLayer:
@@ -306,7 +306,7 @@
     [m_layer setValue:[NSValue valueWithPointer:this] forKey:platformCALayerPointer];
     
     // Clear all the implicit animations on the CALayer
-    if (m_layerType == LayerTypeAVPlayerLayer || m_layerType == LayerTypeContentsProvidedLayer || m_layerType == LayerTypeScrollingLayer || m_layerType == LayerTypeCustom)
+    if (m_layerType == LayerTypeAVPlayerLayer || m_layerType == LayerTypeContentsProvidedLayer || m_layerType == LayerTypeScrollContainerLayer || m_layerType == LayerTypeCustom)
         [m_layer web_disableAllActions];
     else
         [m_layer setDelegate:[WebActionDisablingCALayerDelegate shared]];

Modified: trunk/Source/WebCore/platform/graphics/ca/win/PlatformCALayerWin.cpp (240917 => 240918)

